@@ -1,4 +1,4 @@
-from holour.msg.geometry import Vector3, Pose, Poses
+from holour.msg.geometry import Vector3, Pose, Poses, AxisAngle
 from holour.msg.status import Status
 from holour.msg.force_torque import ForceTorque
 from holour.msg.script import Script, WaypointConfig
